import axios from "axios";
import { generateError } from "./util.js";
const uri = process.env.REACT_APP_BACKEND_URI;
export async function getLeagueById(leagueId) {
    let leagueResponse;
    try {
        leagueResponse = await axios({
            method: "get",
            url: `${uri}/league/id/${leagueId}`,
            responseType: "json",
            withCredentials: true,
        });
    }
    catch (e) {
        throw generateError(e);
    }
    return enrichLeague(leagueResponse.data);
}
export async function getCurrentDayMatches(leagueId) {
    let currentDayResponse;
    try {
        currentDayResponse = await axios({
            method: "get",
            url: `${uri}/match/leagueId/${leagueId}`,
            responseType: "json",
            withCredentials: true,
        });
        currentDayResponse.data.forEach((m) => (m.date = new Date(m.date)));
    }
    catch (e) {
        throw generateError(e);
    }
    return currentDayResponse.data;
}
export async function getResultsFromDay(leagueId, day) {
    let resultsResponse;
    try {
        resultsResponse = await axios({
            method: "get",
            url: `${uri}/match/results/leagueId/${leagueId}/day/${day}`,
            responseType: "json",
            withCredentials: true,
        });
        resultsResponse.data.forEach((m) => (m.date = new Date(m.date)));
    }
    catch (e) {
        throw generateError(e);
    }
    return resultsResponse.data;
}
export async function submitDayPredictions(dayPreds) {
    try {
        await axios({
            method: "put",
            url: `${uri}/match/predictions`,
            data: dayPreds,
            responseType: "json",
            withCredentials: true,
        });
    }
    catch (e) {
        throw generateError(e);
    }
}
export async function authPredictionUser(token) {
    let authResponse;
    try {
        authResponse = await axios({
            method: "post",
            url: `${uri}/auth/`,
            responseType: "json",
            data: { token: token },
            withCredentials: true,
        });
    }
    catch (e) {
        throw generateError(e);
    }
    return authResponse.data;
}
export async function getDayPredictions(userId, leagueId) {
    let dayPredsResponse;
    try {
        dayPredsResponse = await axios({
            method: "get",
            url: `${uri}/match/predictions/userId/${userId}/leagueId/${leagueId}`,
            responseType: "json",
            withCredentials: true,
        });
        dayPredsResponse.data.date = new Date(dayPredsResponse.data.date);
    }
    catch (e) {
        if (e.response?.status === 404) {
            return undefined;
        }
        throw generateError(e);
    }
    return dayPredsResponse.data;
}
export async function getPlayoffPredictions(userId, leagueId) {
    let playoffPredsResponse;
    try {
        playoffPredsResponse = await axios({
            method: "get",
            url: `${uri}/prediction/playoff/userId/${userId}/leagueId/${leagueId}`,
            responseType: "json",
            withCredentials: true,
        });
        playoffPredsResponse.data.date = new Date(playoffPredsResponse.data.date);
    }
    catch (e) {
        if (e.response?.status === 404) {
            return undefined;
        }
        throw generateError(e);
    }
    return playoffPredsResponse.data;
}
export async function submitPlayoffPredictions(playoffPreds) {
    try {
        await axios({
            method: "put",
            url: `${uri}/prediction/playoff`,
            data: playoffPreds,
            responseType: "json",
            withCredentials: true,
        });
    }
    catch (e) {
        throw generateError(e);
    }
}
export async function getLeagueTeams(leagueId) {
    let leagueTeamsResponse;
    try {
        leagueTeamsResponse = await axios({
            method: "get",
            url: `${uri}/league/id/${leagueId}/teams`,
            responseType: "json",
            withCredentials: true,
        });
    }
    catch (e) {
        throw generateError(e);
    }
    return leagueTeamsResponse.data;
}
function enrichLeague(league) {
    const ldm = getLeagueDaysMap(league.leagueDays);
    const usm = getUserTotalScoresMap(league.userScores);
    const enrichedLeague = {
        id: league.id,
        name: league.name,
        tournamentId: league.tournamentId,
        tournamentName: league.tournamentName,
        finished: league.finished,
        daysMap: ldm,
        userScores: usm,
        maxScore: league.maxScore,
        settings: league.settings,
    };
    return enrichedLeague;
}
function getUserTotalScoresMap(userScores) {
    const usm = new Map();
    userScores.forEach((us) => {
        usm.set(us.user, us.score);
    });
    return usm;
}
function getPredictionsMap(predictions) {
    const predsMap = new Map();
    predictions.forEach((apiPrediction) => {
        const prediction = {
            matchId: apiPrediction.matchId,
            predictionTeamId: apiPrediction.predictionTeamId,
            wasCorrect: apiPrediction.wasCorrect,
        };
        predsMap.set(apiPrediction.matchId, prediction);
    });
    return predsMap;
}
function getUserDayScoresMap(userDayScores) {
    const usm = new Map();
    userDayScores.forEach((apiUserDayScore) => {
        const userDayScore = {
            user: apiUserDayScore.user,
            dayNumber: apiUserDayScore.dayNumber,
            dayScore: apiUserDayScore.dayScore,
            runningDayScore: apiUserDayScore.runningDayScore,
            predictions: getPredictionsMap(apiUserDayScore.predictions),
        };
        usm.set(apiUserDayScore.user.id, userDayScore);
    });
    return usm;
}
function getLeagueDaysMap(leagueDays) {
    const ldm = new Map();
    leagueDays.forEach((apiLeagueDay) => {
        const leagueDay = {
            day: apiLeagueDay.day,
            userScores: getUserDayScoresMap(apiLeagueDay.userDayScores),
            maxScore: apiLeagueDay.maxScore,
            maxRunningDayScore: apiLeagueDay.maxRunningDayScore,
        };
        ldm.set(apiLeagueDay.day, leagueDay);
    });
    return ldm;
}
